@@ -1,3 +1,4 @@
+"""Module with lib binding methods"""
 import ctypes
 import json
 import os
@@ -15,11 +16,7 @@ LIB_FILENAME = 'ton-rust-client'
 def _get_lib_path():
     machine = platform.machine().lower()
     system = platform.system().lower()
-    system_ext = {
-        'windows': 'dll',
-        'darwin': 'dylib',
-        'linux': 'so'
-    }
+    system_ext = {'windows': 'dll', 'darwin': 'dylib', 'linux': 'so'}
     ext = system_ext.get(system, '')
 
     # Try to load binary for system and machine type
@@ -31,7 +28,8 @@ def _get_lib_path():
     fallback = os.path.join(LIB_DIR, f'{LIB_FILENAME}.{ext}')
     if not os.path.exists(fallback):
         raise RuntimeError(
-            f'No library for machine `{machine}` and platform `{system}`')
+            f'No library for machine `{machine}` and platform `{system}`'
+        )
     return fallback
 
 
@@ -39,8 +37,9 @@ _LIB = ctypes.cdll.LoadLibrary(_get_lib_path())
 
 
 def tc_create_context(
-        config: Dict[str, Dict[str, Union[str, int, float]]]
+    config: Dict[str, Dict[str, Union[str, int, float]]]
 ) -> ctypes.POINTER(ctypes.c_char_p):
+    """Create client context"""
     _config = TCStringData.from_string(string=json.dumps(config))
 
     _LIB.tc_create_context.restype = ctypes.POINTER(ctypes.c_char_p)
@@ -48,24 +47,30 @@ def tc_create_context(
 
 
 def tc_destroy_context(ctx: ctypes.c_int32):
+    """Destroy client context"""
     _LIB.tc_destroy_context(ctx)
 
 
 def tc_request(
-        ctx: ctypes.c_int32, method: str, request_id: int,
-        response_handler: TCResponseHandler, params_json: str = None):
+    ctx: ctypes.c_int32,
+    method: str,
+    request_id: int,
+    response_handler: TCResponseHandler,
+    params_json: str = None,
+):
+    """Make async request"""
     # Cast args to ctypes
     method = TCStringData.from_string(string=method)
     request_id = ctypes.c_int32(request_id)
     params_json = TCStringData.from_string(string=params_json)
 
-    _LIB.tc_request(
-        ctx, method, params_json, request_id, response_handler)
+    _LIB.tc_request(ctx, method, params_json, request_id, response_handler)
 
 
 def tc_request_sync(
-        ctx: ctypes.c_int32, method: str, params_json: str = None
+    ctx: ctypes.c_int32, method: str, params_json: str = None
 ) -> ctypes.POINTER(ctypes.c_char_p):
+    """Make sync request (might be deprecated)"""
     method = TCStringData.from_string(string=method)
     params_json = TCStringData.from_string(string=params_json)
 
@@ -74,9 +79,11 @@ def tc_request_sync(
 
 
 def tc_destroy_string(string: ctypes.POINTER(ctypes.c_char_p)):
+    """Destroy string"""
     _LIB.tc_destroy_string(string)
 
 
 def tc_read_string(string: ctypes.POINTER(ctypes.c_char_p)) -> TCStringData:
+    """Read string"""
     _LIB.tc_read_string.restype = TCStringData
     return _LIB.tc_read_string(string)
